Class: Module

Inherits:
Object show all
Defined in:
lib/rubyexts/module.rb,
lib/rubyexts/try_dup.rb

Overview

Extends the module object with module and instance accessors for class attributes, just like the native attr* accessors for instance attributes.

module AppConfiguration
  mattr_accessor :google_api_key
  self.google_api_key = "123456789"

  mattr_accessor :paypal_url
  self.paypal_url = "www.sandbox.paypal.com"
end

AppConfiguration.google_api_key = "overriding the api key!"

Instance Method Summary collapse

Instance Method Details

#mattr_accessor(*syms) ⇒ Object



49
50
51
52
# File 'lib/rubyexts/module.rb', line 49

def mattr_accessor(*syms)
  mattr_reader(*syms)
  mattr_writer(*syms)
end

#mattr_reader(*syms) ⇒ Object



16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
# File 'lib/rubyexts/module.rb', line 16

def mattr_reader(*syms)
  syms.each do |sym|
    next if sym.is_a?(Hash)
    class_eval(<<-EOS, __FILE__, __LINE__)
      unless defined? @@#{sym}
        @@#{sym} = nil
      end

      def self.#{sym}
        @@#{sym}
      end

      def #{sym}
        @@#{sym}
      end
    EOS
  end
end

#mattr_writer(*syms) ⇒ Object



35
36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/rubyexts/module.rb', line 35

def mattr_writer(*syms)
  syms.each do |sym|
    class_eval(<<-EOS, __FILE__, __LINE__)
      unless defined? @@#{sym}
        @@#{sym} = nil
      end

      def self.#{sym}=(obj)
        @@#{sym} = obj
      end
    EOS
  end
end

#try_dupObject



40
41
42
# File 'lib/rubyexts/try_dup.rb', line 40

def try_dup
  self
end